<?php
/**
 * Copyright (C) 2025  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Civi\ActionProvider\Actions\UtmTracking;

use Civi\ActionProvider\Action\AbstractAction;
use Civi\ActionProvider\Parameter\ParameterBagInterface;
use Civi\ActionProvider\Parameter\Specification;
use Civi\ActionProvider\Parameter\SpecificationBag;
use Civi\API\Exception\UnauthorizedException;
use Civi\Api4\Utmtracking;
use CRM_Utmtracking_ExtensionUtil as E;

class CreateUtmTracking extends AbstractAction {
  /**
   * Run the action
   *
   * @param ParameterBagInterface $parameters
   *   The parameters to this action.
   * @param ParameterBagInterface $output
   *   The parameters this action can send back
   * @return void
   */
  protected function doAction(ParameterBagInterface $parameters, ParameterBagInterface $output)
  {
    $values = [];
    if ($parameters->doesParameterExists('utm_source')) {
      $values['utm_source'] = $parameters->getParameter('utm_source');
    }
    if ($parameters->doesParameterExists('utm_campaign')) {
      $values['utm_campaign'] = $parameters->getParameter('utm_campaign');
    }
    if ($parameters->doesParameterExists('utm_medium')) {
      $values['utm_medium'] = $parameters->getParameter('utm_medium');
    }
    if ($parameters->doesParameterExists('contribution_id')) {
      $values['contribution_id'] = $parameters->getParameter('contribution_id');
    }
    if ($parameters->doesParameterExists('contribution_recur_id')) {
      $values['contribution_recur_id'] = $parameters->getParameter('contribution_recur_id');
    }
    if ($parameters->doesParameterExists('activity_id')) {
      $values['activity_id'] = $parameters->getParameter('activity_id');
    }
    if ($parameters->doesParameterExists('membership_id')) {
      $values['membership_id'] = $parameters->getParameter('membership_id');
    }
    if ($parameters->doesParameterExists('participant_id')) {
      $values['participant_id'] = $parameters->getParameter('participant_id');
    }

    if (!empty($values)) {
      try {
        Utmtracking::create(FALSE)
          ->setValues($values)
          ->execute();
      } catch (UnauthorizedException|\CRM_Core_Exception $e) {
        // Do nothing
      }
    }
  }

  /**
   * Returns the specification of the configuration options for the actual action.
   *
   * @return SpecificationBag
   */
  public function getConfigurationSpecification()
  {
    return new SpecificationBag([]);
  }

  /**
   * Returns the specification of the parameters of the actual action.
   *
   * @return SpecificationBag
   */
  public function getParameterSpecification()
  {
    return new SpecificationBag([
      new Specification('utm_source','String', E::ts('UTM Source'), false),
      new Specification('utm_campaign','String', E::ts('UTM Campaign'), false),
      new Specification('utm_medium','String', E::ts('UTM Medium'), false),
      new Specification('contribution_id', 'Integer', E::ts('Contribution ID'), false),
      new Specification('contribution_recur_id', 'Integer', E::ts('Contribution Recur ID'), false),
      new Specification('activity_id', 'Integer', E::ts('Activity ID'), false),
      new Specification('membership_id', 'Integer', E::ts('Membership ID'), false),
      new Specification('participant_id', 'Integer', E::ts('Participant ID'), false),
    ]);
  }


}