<?php
/**
 * Copyright (C) 2025  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Civi\UtmTracking;

use CRM_Utmtracking_ExtensionUtil as E;
use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;

class CompilerPass implements CompilerPassInterface {
  /**
   * You can modify the container here before it is dumped to PHP code.
   */
  public function process(ContainerBuilder $container)
  {
    if ($container->hasDefinition('action_provider')) {
      $actionTypeFactoryDefinition = $container->getDefinition('action_provider');
      $actionTypeFactoryDefinition->addMethodCall('addAction', [
        'utmtracking_create',
        'Civi\ActionProvider\Actions\UtmTracking\CreateUtmTracking',
        E::ts('UTM Tracking: Create UTM Tracking record'),
        [
          \Civi\ActionProvider\Action\AbstractAction::DATA_MANIPULATION_TAG,
          \Civi\ActionProvider\Action\AbstractAction::WITHOUT_CONTACT_ACTION_TAG
        ],
      ]);
    }
    if ($container->hasDefinition('data_processor_factory')) {
      $factoryDefinition = $container->getDefinition('data_processor_factory');
      $factoryDefinition->addMethodCall('addDataSource', [
        'utmtracking',
        'Civi\DataProcessor\Source\UtmTracking',
        E::ts('UTM Tracking'),
      ]);
    }
  }


}